summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/classgenpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/classgenpage.h')
-rw-r--r--umbrello/umbrello/dialogs/classgenpage.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/umbrello/umbrello/dialogs/classgenpage.h b/umbrello/umbrello/dialogs/classgenpage.h
index 4d661ae1..d6d06a50 100644
--- a/umbrello/umbrello/dialogs/classgenpage.h
+++ b/umbrello/umbrello/dialogs/classgenpage.h
@@ -38,35 +38,36 @@ class UMLDoc;
*/
class ClassGenPage : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Sets up the ClassGenPage.
*
* @param d The UMLDoc which controls controls object creation.
* @param parent The parent to the ClassGenPage.
* @param o The UMLObject to display the properties of.
*/
- ClassGenPage(UMLDoc *d, TQWidget *parent, UMLObject * o);
+ ClassGenPage(UMLDoc *d, TQWidget *tqparent, UMLObject * o);
/**
* Sets up the ClassGenPage for an ObjectWidget
*
* @param d The UMLDoc which controls controls object creation.
* @param parent The parent to the ClassGenPage.
* @param o The ObjectWidget to display the properties of.
*/
- ClassGenPage(UMLDoc *d, TQWidget *parent, ObjectWidget * o);
+ ClassGenPage(UMLDoc *d, TQWidget *tqparent, ObjectWidget * o);
/**
* Sets up the ClassGenPage for a UMLWidget instance (used
* for component instances on deployment diagrams)
*
* @param d The UMLDoc which controls controls object creation.
* @param parent The parent to the ClassGenPage.
* @param widget The UMLWidget to display the properties of.
*/
- ClassGenPage(UMLDoc* d, TQWidget* parent, UMLWidget* widget);
+ ClassGenPage(UMLDoc* d, TQWidget* tqparent, UMLWidget* widget);
/**
* Standard deconstructor.
@@ -38,35 +38,36 @@ class UMLDoc;
*
* @param d The UMLDoc which controls controls object creation.
- * @param parent The parent to the ClassGenPage.
+ * @param tqparent The tqparent to the ClassGenPage.
* @param o The UMLObject to display the properties of.
*/
@@ -38,35 +38,36 @@ class UMLDoc;
*
* @param d The UMLDoc which controls controls object creation.
- * @param parent The parent to the ClassGenPage.
+ * @param tqparent The tqparent to the ClassGenPage.
* @param o The ObjectWidget to display the properties of.
*/
@@ -38,35 +38,36 @@ class UMLDoc;
*
* @param d The UMLDoc which controls controls object creation.
- * @param parent The parent to the ClassGenPage.
+ * @param tqparent The tqparent to the ClassGenPage.
* @param widget The UMLWidget to display the properties of.
*/